# Volte Norway Grid Tariff Calculator


<p align="center">
<a href="https://pypi.python.org/pypi/grid_tariff_calculator">
    <img src="https://img.shields.io/pypi/v/grid_tariff_calculator.svg"
        alt = "Release Status">
</a>

<a href="https://github.com/bkkas/grid_tariff_calculator/actions">
    <img src="https://github.com/bkkas/grid_tariff_calculator/actions/workflows/main.yml/badge.svg?branch=release" alt="CI Status">
</a>

<a href="https://bkkas.github.io/grid_tariff_calculator/">
    <img src="https://img.shields.io/website/https/bkkas.github.io/grid_tariff_calculator/index.html.svg?label=docs&down_message=unavailable&up_message=available" alt="Documentation Status">
</a>

</p>


Library to calculate the grid tariffs in Norway


* Free software: MIT
* Documentation: <https://bkkas.github.io/grid_tariff_calculator/>


## Features

* TODO

## Credits

This package was created with the [ppw](https://zillionare.github.io/python-project-wizard) tool. For more information, please visit the [project page](https://zillionare.github.io/python-project-wizard/).
